import * as dotenv from 'dotenv';


dotenv.config();

/**
 * Checks if the password gives admin privileges (view / create / edit / delete)
 * @param password
 */
export const checkAdminPrivileges = (password: string) => {
	return password == process.env.ADMIN_CREDENTIAL;
}

/**
 * Checks if the password gives member view privileges
 * @param password
 */
export const checkMemberPrivileges = (password: string) => {
	return password == process.env.MEMBER_CREDENTIAL || password == process.env.ADMIN_CREDENTIAL;
}

/**
 * Checks if the password gives management view privileges
 * @param password
 */
export const checkManagementPrivileges = (password: string) => {
	return password == process.env.MANAGEMENT_CREDENTIAL || password == process.env.ADMIN_CREDENTIAL;
}

export const hasAccess = (calendarName: string, password: string) => {
	switch (calendarName) {
		case 'public':
			return true;
		case 'members':
			return checkMemberPrivileges(password);
		case 'management':
			return checkManagementPrivileges(password);
		default:
			return false;
	}
}
